==> nextcloud-php74-20.0.7.txz: usr/local/www/nextcloud/apps-pkg/updatenotification/l10n/ja.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} が利用可能です。アップデート方法について詳細情報を確認してください。",
    "Channel updated" : "チャンネルを更新しました",
    "Update notifications" : "アップデート通知",
    "The update server could not be reached since %d days to check for new updates." : "%d日以降、新しい更新をチェックする更新サーバーにアクセスできませんでした。",
    "Please check the Nextcloud and server log files for errors." : "Nextcloudとサーバーログファイルでエラーがないか確認してください。",
    "Update to %1$s is available." : "%1$s への更新が利用可能です。",
    "Update for %1$s to version %2$s is available." : "%1$s に対するバージョン %2$s へアップデートが利用可能です。",
    "Update for {app} to version %s is available." : " {app} に対するバージョン %s へアップデートが利用可能です。",
    "Update notification" : "アップデート通知",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Nextcloudの更新通知を表示し、アップデータのSSOを提供します。",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "あなたが実行しているバージョンはもうサポートされていません。 サポートされているバージョンにすみやかにアップデートしてください。",
    "Apps missing updates" : "アプリのアップデートがありません",
    "View in store" : "ストア内で表示",
    "Apps with available updates" : "アップデート可能なアプリ",
    "Open updater" : "アップデーターを開く",
    "Download now" : "今すぐダウンロード",
    "What's new?" : "新着情報？",
    "The update check is not yet finished. Please refresh the page." : "アップデートチェックが完了していません。ページを更新してください。",
    "Your version is up to date." : "最新版です。",
    "A non-default update server is in use to be checked for updates:" : "更新のチェックにデフォルト以外の更新サーバーが利用されています:",
    "Update channel:" : "アップデートチャンネル:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "いつでも新しいバージョンにアップデートすることができます。 ただし、下位の安定したバージョンにダウングレードすることはできません",
    "Notify members of the following groups about available updates:" : "次のグループのメンバーに利用可能なアップデートを通知する:",
    "Only notification for app updates are available." : "アプリ更新情報があるときのみ通知する。",
    "The selected update channel makes dedicated notifications for the server obsolete." : "選択した更新チャネルでは、廃止サーバーについて専用の通知を行います。",
    "The selected update channel does not support updates of the server." : "選択したチャンネルでは、サーバーのアップデートをサポートしていません。",
    "A new version is available: <strong>{newVersionString}</strong>" : "新しいバージョンが利用可能です: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "{lastCheckedDate} にチェックが入っています",
    "Checking apps for compatible updates" : "互換性のあるアップデートの有無を確認する",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "config.phpで<samp>appstoreenabled</samp>がfalseに設定されていないことを確認してください。",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Appstoreに接続できなかったか、Appstoreからアップデートが返されませんでした。アップデートを手動で検索するか、サーバーがインターネットへアクセスでき、Appstoreに接続できることを確認してください。",
    "<strong>All</strong> apps have an update for this version available" : "<strong>すべての</strong> アプリにこのバージョンのアップデートがあります",
    "View changelog" : "変更履歴を確認する",
    "Enterprise" : "エンタープライズ",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "企業用です。 常に最新のパッチレベルを提供しますが、すぐに次のメジャーリリースにアップデートはしません。このアップデートはNextcloud GmbHが大規模でミッションクリティカルな開発のための追加の強化とテストを行った後に行われます。 このチャンネルは顧客だけが利用でき、Nextcloud Enterpriseパッケージを提供します。",
    "Stable" : "安定版",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "最新の安定版です。 通常の使用に適しており、常に最新のメジャーバージョンにアップデートされます。",
    "Beta" : "ベータ",
    "A pre-release version only for testing new features, not for production environments." : "本番環境ではなく、新機能のテスト専用のプレリリース版です。",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> アプリにこのバージョンのアップデートがありません"],
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "新しいリリースの後、公開されるまでには時間がかかります。\n新しいバージョンを公開して配布しますが、問題が発見されたときにバージョンをスキップすることがあります。"
},
"nplurals=1; plural=0;");

==> nextcloud-php74-21.0.2.txz: usr/local/www/nextcloud/apps-pkg/updatenotification/l10n/ja.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} が利用可能です。アップデート方法について詳細情報を確認してください。",
    "Channel updated" : "チャンネルを更新しました",
    "Web updater is disabled" : "Webアップデータは無効になっています",
    "Update notifications" : "アップデート通知",
    "The update server could not be reached since %d days to check for new updates." : "%d日以降、新しい更新をチェックする更新サーバーにアクセスできませんでした。",
    "Please check the Nextcloud and server log files for errors." : "Nextcloudとサーバーログファイルでエラーがないか確認してください。",
    "Update to %1$s is available." : "%1$s への更新が利用可能です。",
    "Update for %1$s to version %2$s is available." : "%1$s に対するバージョン %2$s へアップデートが利用可能です。",
    "Update for {app} to version %s is available." : " {app} に対するバージョン %s へアップデートが利用可能です。",
    "Update notification" : "アップデート通知",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Nextcloudの更新通知を表示し、アップデータのSSOを提供します。",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "あなたが実行しているバージョンはもうサポートされていません。 サポートされているバージョンにすみやかにアップデートしてください。",
    "Apps missing compatible version" : "対応バージョンがないアプリ",
    "View in store" : "ストア内で表示",
    "Apps with compatible version" : "対応バージョンのあるアプリ",
    "Open updater" : "アップデーターを開く",
    "Download now" : "今すぐダウンロード",
    "Please use the command line updater to update." : "コマンドラインアップデーターを使ってアップデートしてください。",
    "What's new?" : "新着情報？",
    "The update check is not yet finished. Please refresh the page." : "アップデートチェックが完了していません。ページを更新してください。",
    "Your version is up to date." : "最新版です。",
    "A non-default update server is in use to be checked for updates:" : "更新のチェックにデフォルト以外の更新サーバーが利用されています:",
    "Update channel:" : "アップデートチャンネル:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "いつでも新しいバージョンにアップデートすることができます。 ただし、下位の安定したバージョンにダウングレードすることはできません",
    "Notify members of the following groups about available updates:" : "次のグループのメンバーに利用可能なアップデートを通知する:",
    "Only notifications for app updates are available." : "アプリのアップデートの通知のみが可能です。",
    "The selected update channel makes dedicated notifications for the server obsolete." : "選択した更新チャネルでは、廃止サーバーについて専用の通知を行います。",
    "The selected update channel does not support updates of the server." : "選択したチャンネルでは、サーバーのアップデートをサポートしていません。",
    "A new version is available: <strong>{newVersionString}</strong>" : "新しいバージョンが利用可能です: <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "新しいリリースの後、アップデートは最初のマイナーリリース以降にのみ表示されることに注意してください。新しいバージョンは時間の経過とともにユーザーに公開され、問題が見つかった場合はバージョンをスキップすることがあります。アップデートとリリースチャネルの詳細については、{link}をご覧ください。",
    "Checked on {lastCheckedDate}" : "{lastCheckedDate} にチェックが入っています",
    "Checking apps for compatible versions" : "アプリの互換性のあるバージョンを確認する",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "config.phpで<samp>appstoreenabled</samp>がfalseに設定されていないことを確認してください。",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Appstoreに接続できなかったか、Appstoreからアップデートが返されませんでした。アップデートを手動で検索するか、サーバーがインターネットへアクセスでき、Appstoreに接続できることを確認してください。",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available" : "<strong>すべて</strong>のアプリが、このNextcloudのバージョンに対応しています。",
    "View changelog" : "変更履歴を確認する",
    "Enterprise" : "法人向け",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "法人向けです。 常に最新のパッチレベルを提供しますが、すぐに次のメジャーリリースにアップデートはしません。このアップデートはNextcloud GmbHが大規模でミッションクリティカルな開発のための追加の強化とテストを行った後に行われます。 このチャンネルは顧客だけが利用でき、Nextcloud Enterpriseパッケージを提供します。",
    "Stable" : "安定版",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "最新の安定版です。 通常の使用に適しており、常に最新のメジャーバージョンにアップデートされます。",
    "Beta" : "ベータ",
    "A pre-release version only for testing new features, not for production environments." : "本番環境ではなく、新機能のテスト専用のプレリリース版です。",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available_::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available_" : ["アプリ<strong>%n</strong> には、このNextcloudに互換性のあるバージョンがありません。"],
    "Apps missing updates" : "アプリのアップデートがありません",
    "Apps with available updates" : "アップデート可能なアプリ",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "新しいリリースの後、公開されるまでには時間がかかります。\n新しいバージョンを公開して配布しますが、問題が発見されたときにバージョンをスキップすることがあります。",
    "Only notification for app updates are available." : "アプリ更新情報があるときのみ通知する。",
    "Checking apps for compatible updates" : "互換性のあるアップデートの有無を確認する",
    "<strong>All</strong> apps have an update for this version available" : "<strong>すべての</strong> アプリにこのバージョンのアップデートがあります",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> アプリにこのバージョンのアップデートがありません"]
},
"nplurals=1; plural=0;");
